[![Tests](https://github.com/uwefladrich/scriptengine-tasks-ecearth/actions/workflows/pytest.yml/badge.svg)](https://github.com/uwefladrich/scriptengine-tasks-ecearth/actions)
[![Coverage Status](https://coveralls.io/repos/github/uwefladrich/scriptengine-tasks-ecearth/badge.svg)](https://coveralls.io/github/uwefladrich/scriptengine-tasks-ecearth)

# ScriptEngine Tasks for EC-Earth

Provides [ScriptEngine](https://github.com/uwefladrich/scriptengine) tasks useful for the EC-Earth climate model.

This package is currently being developed. The documentation can be found on [ReadTheDocs](https://scriptengine-tasks-ecearth.rtfd.io).

## Contributing

1. See the documentation for hints on [installation from source (and how to run tests)](https://scriptengine-tasks-ecearth.readthedocs.io/en/latest/source/getting-started/installation.html#installation-from-source).
2. See the documentation for [hints on code formatting, structure, naming schemes, etc.](https://scriptengine-tasks-ecearth.readthedocs.io/en/latest/source/tasks/monitoring/developer-guide.html)
3. Have a look at issues labeled ["good first issue"](https://github.com/uwefladrich/scriptengine-tasks-ecearth/issues?q=is%3Aissue+is%3Aopen+label%3A%22good+first+issue%22) for a place to start! :)